<html>
<head>
<title>$title - $version</title>
</head>
<body>
<form>
<select name="names">
<!--{1}--><option $selected>$list <!--("hdias","anita","cubitos")--></option>
<!--{2}--></select>
</form>
</body>
</html>
