<html>
<head>
<title>$title - $version</title>
</head>
<body>
<form>
<select name="names">
<option value="">-- Select --</option>
<!--{1}--><option value="$value" $selected>$list</option>
<!--{1.1}--><option style="background-color: #ffd700;" value="$value" $selected>$list</option>
<!--{1.2}--><option color="#ff0000" value="$value" $selected>$list</option>
<!--{2}--></select>
</form>
</body>
</html>
